Virtual Keyboard Basic Demo

# Virtual Keyboard Alt-Keys Popup Demo

#### Note: Look at this demo source or refer to the documentation on how to set up this extension.

- Click or press and hold any of the following keys to see a popup:
  - Extension defaults: `1234567890acdeghijklnorstuwyz'ACDEGHIJKLNORSTUWYZ!$()"?`
  - Demo extras: `[`, `]`, `enter`, `☺` & `✙` (examine the source code of this page to see how these were added).
- The keys within the popup are completely customizable. In fact they can include any action key (click or press and hold the enter key).